summaryrefslogtreecommitdiffstats
path: root/src/fetch/imdbfetcher.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/fetch/imdbfetcher.cpp')
-rw-r--r--src/fetch/imdbfetcher.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/src/fetch/imdbfetcher.cpp b/src/fetch/imdbfetcher.cpp
index 5db3a49..d70429f 100644
--- a/src/fetch/imdbfetcher.cpp
+++ b/src/fetch/imdbfetcher.cpp
@@ -74,7 +74,7 @@ void IMDBFetcher::initRegExps() {
s_titleRx->setMinimal(true);
}
-IMDBFetcher::IMDBFetcher(TQObject* tqparent_, const char* name_) : Fetcher(tqparent_, name_),
+IMDBFetcher::IMDBFetcher(TQObject* parent_, const char* name_) : Fetcher(parent_, name_),
m_job(0), m_started(false), m_fetchImages(true), m_host(TQString::tqfromLatin1(IMDB_SERVER)),
m_limit(IMDB_MAX_RESULTS), m_countOffset(0) {
if(!s_tagRx) {
@@ -261,10 +261,10 @@ void IMDBFetcher::slotComplete(KIO::Job* job_) {
void IMDBFetcher::parseSingleTitleResult() {
// myDebug() << "IMDBFetcher::parseSingleTitleResult()" << endl;
s_titleRx->search(Tellico::decodeHTML(TQString(m_data)));
- // split title at tqparenthesis
+ // split title at parenthesis
const TQString cap1 = s_titleRx->cap(1);
int pPos = cap1.tqfind('(');
// FIXME: maybe remove tqparentheses here?
SearchResult* r = new SearchResult(this,
pPos == -1 ? cap1 : cap1.left(pPos),
pPos == -1 ? TQString() : cap1.mid(pPos),
@@ -344,11 +344,11 @@ void IMDBFetcher::parseTitleBlock(const TQString& str_) {
int count = 0;
int start = s_anchorTitleRx->search(str_);
while(m_started && start > -1) {
- // split title at tqparenthesis
+ // split title at parenthesis
const TQString cap1 = s_anchorTitleRx->cap(1); // the anchor url
const TQString cap2 = s_anchorTitleRx->cap(2).stripWhiteSpace(); // the anchor text
start += s_anchorTitleRx->matchedLength();
- int pPos = cap2.tqfind('('); // if it has tqparentheses, use that for description
+ int pPos = cap2.tqfind('('); // if it has parentheses, use that for description
TQString desc;
if(pPos > -1) {
int pPos2 = cap2.tqfind(')', pPos+1);
@@ -356,7 +356,7 @@ void IMDBFetcher::parseTitleBlock(const TQString& str_) {
desc = cap2.mid(pPos+1, pPos2-pPos-1);
}
} else {
- // tqparenthesis might be outside anchor tag
+ // parenthesis might be outside anchor tag
int end = s_anchorTitleRx->search(str_, start);
if(end == -1) {
end = str_.length();
@@ -434,7 +434,7 @@ void IMDBFetcher::parseSingleNameResult() {
desc.truncate(0);
bool isEpisode = false;
len = s_anchorTitleRx->cap(0).length();
- // split title at tqparenthesis
+ // split title at parenthesis
const TQString cap2 = s_anchorTitleRx->cap(2).stripWhiteSpace();
int pPos = cap2.tqfind('(');
if(pPos > -1) {
@@ -479,7 +479,7 @@ void IMDBFetcher::parseSingleNameResult() {
break;
}
// FIXME: maybe remove tqparentheses here?
SearchResult* r = new SearchResult(this, pPos == -1 ? cap2 : cap2.left(pPos), desc, TQString());
KURL u(m_url, s_anchorTitleRx->cap(1)); // relative URL constructor
u.setQuery(TQString());
@@ -528,7 +528,7 @@ void IMDBFetcher::parseMultipleNameResults() {
while(pos > -1 && pos < end && m_matches.size() < m_limit) {
KURL u(m_url, s_anchorNameRx->cap(1));
s = s_anchorNameRx->cap(2).stripWhiteSpace() + ' ';
- // if more than one exact, add tqparentheses
+ // if more than one exact, add parentheses
if(nameMap.tqcontains(s) && nameMap[s] > 0) {
// fix the first one that didn't have a number
if(nameMap[s] == 1) {
@@ -700,7 +700,7 @@ Tellico::Data::EntryPtr IMDBFetcher::parseEntry(const TQString& str_) {
void IMDBFetcher::doTitle(const TQString& str_, Data::EntryPtr entry_) {
if(s_titleRx->search(str_) > -1) {
const TQString cap1 = s_titleRx->cap(1);
// titles always have tqparentheses
int pPos = cap1.tqfind('(');
TQString title = cap1.left(pPos).stripWhiteSpace();
// remove first and last quotes is there
@@ -708,7 +708,7 @@ void IMDBFetcher::doTitle(const TQString& str_, Data::EntryPtr entry_) {
title = title.mid(1, title.length()-2);
}
entry_->setField(TQString::tqfromLatin1("title"), title);
- // remove tqparenthesis
+ // remove parenthesis
uint pPos2 = pPos+1;
while(pPos2 < cap1.length() && cap1[pPos2].isDigit()) {
++pPos2;
@@ -1123,12 +1123,12 @@ void IMDBFetcher::updateEntry(Data::EntryPtr entry_) {
emit signalDone(this); // always need to emit this if not continuing with the search
}
-Tellico::Fetch::ConfigWidget* IMDBFetcher::configWidget(TQWidget* tqparent_) const {
- return new IMDBFetcher::ConfigWidget(tqparent_, this);
+Tellico::Fetch::ConfigWidget* IMDBFetcher::configWidget(TQWidget* parent_) const {
+ return new IMDBFetcher::ConfigWidget(parent_, this);
}
-IMDBFetcher::ConfigWidget::ConfigWidget(TQWidget* tqparent_, const IMDBFetcher* fetcher_/*=0*/)
- : Fetch::ConfigWidget(tqparent_) {
+IMDBFetcher::ConfigWidget::ConfigWidget(TQWidget* parent_, const IMDBFetcher* fetcher_/*=0*/)
+ : Fetch::ConfigWidget(parent_) {
TQGridLayout* l = new TQGridLayout(optionsWidget(), 4, 2);
l->setSpacing(4);
l->setColStretch(1, 10);
@@ -261,10 +261,10 @@ void IMDBFetcher::slotComplete(KIO::Job* job_) {
const TQString cap1 = s_titleRx->cap(1);
int pPos = cap1.tqfind('(');
- // FIXME: maybe remove tqparentheses here?
+ // FIXME: maybe remove parentheses here?
SearchResult* r = new SearchResult(this,
pPos == -1 ? cap1 : cap1.left(pPos),
@@ -479,7 +479,7 @@ void IMDBFetcher::parseSingleNameResult() {
break;
}
- // FIXME: maybe remove tqparentheses here?
+ // FIXME: maybe remove parentheses here?
SearchResult* r = new SearchResult(this, pPos == -1 ? cap2 : cap2.left(pPos), desc, TQString());
KURL u(m_url, s_anchorTitleRx->cap(1)); // relative URL constructor
@@ -700,7 +700,7 @@ Tellico::Data::EntryPtr IMDBFetcher::parseEntry(const TQString& str_) {
if(s_titleRx->search(str_) > -1) {
const TQString cap1 = s_titleRx->cap(1);
- // titles always have tqparentheses
+ // titles always have parentheses
int pPos = cap1.tqfind('(');
TQString title = cap1.left(pPos).stripWhiteSpace();